<?php
/*
** @name: dialog_img.php
**
** @description: controller for plan images dialog windows
** @author: Quentin George <q.george@esia-sa.com>
** @date: 06/04/2022
*/

$path = $_SERVER['DOCUMENT_ROOT'];
include_once $path . '/plugin/plan/inc/common_dialog_plan.inc.php';
include_once LIB_PLAN_IMG;

try
{
	if($action == 'updateObjContainer')
	{
		// Get plan user access
		$access = Model_plan::getPlanUserAccess($dbconnection, $planId, $user->getId());

		if(isset($_POST['confirmIdPlan']) && $_POST['confirmIdPlan'] == $planId)
		{
			/*
			** Validation form sended
			*/
			if(!$isUserPerms['admin'] || ($access != 'WRITE' && $access != 'CREATOR'))
			{
				throw new \Exception('Cannot update this plan object ! User privilege missing.');
			}

			if(!empty($_POST['object_id']))
			{
				$objParams = array();
				if(is_numeric($_POST['object_id']))
				{
					$_POST['object_id'] = intval($_POST['object_id']);
					$obj = Model_plan::instanceObjectPlans($dbconnection, $planId, array($_POST['object_id']), FALSE, DEFAULT_ADM_STATES)[$_POST['object_id']];
					$objParams = $obj->getParams();
				}
				else
				{
					// New object not saved in DB yet
					$obj = new \Plan\ObjectPlan();
					$obj->setState(DEFAULT_ADM_STATES);
					if(isset($_POST['obj_params_old']))
					{
						$objParams = json_decode($_POST['obj_params_old'], TRUE);
					}
				}
				$obj->setIconId($_POST['iconObj']);
				
				// Set object linked elements
				$objParams['groups'] = '';
				$objParams['nodes'] = '';
				$objParams['services'] = '';
				if(!empty($_POST['selectGroups']))
				{
					$objParams['groups'] = implode(',', $_POST['selectGroups']);
				}
				if(!empty($_POST['selectNodes']))
				{
					$objParams['nodes'] = implode(',', $_POST['selectNodes']);
				}
				if(!empty($_POST['selectServices']))
				{
					$objParams['services'] = implode(',', $_POST['selectServices']);
				}
				// Linked plan
				if(!empty($_POST['selectPlan']))
				{
					$obj->setLinkPlanId($_POST['selectPlan']);
				}
				else
				{
					$obj->setLinkPlanId(0); // Will be set to null in DB
				}

				// Object common params
				if(!empty($_POST['objName']))
				{
					$obj->setName(str_replace(NAME_FORBIDDEN_CHARS, NAME_REPLACEMENT_CHAR, trim($_POST['objName'])));
				}
				if(isset($_POST['objNotstate']))
				{
					$objParams['getstate'] = 'no';
				}
				else
				{
					$objParams['getstate'] = 'yes';
				}

				$obj->setParams($objParams);

				if(!empty($obj->getId()) && is_numeric($obj->getId()))
				{
					Model_plan::updateObject($dbconnection, $obj->getId(), $planId, $obj->getName(), json_encode($obj->getParams()), $obj->getIconId(), $obj->getLinkPlanId());
				}
				else
				{
					// tmp id means that it's a new object not saved in DB yet
					$newId = Model_plan::addObject($dbconnection, $planId, $obj->getName(), 'container', json_encode($obj->getParams()), $obj->getIconId(), $obj->getLinkPlanId());
					$obj->setId($newId);
				}

				// Fetch new icon data
				$newIcon = Model_plan::getIcons($dbconnection, $obj->getIconId())[0];
				$obj->setIconName($newIcon['name']);
				$obj->setIconType($newIcon['type']);
				$obj->setIconPath($newIcon['path']);

				$objArr = $obj->toArray($path);
				$objArr['old_id'] = $_POST['object_id']; // Save old object Id to update the object on the plan

				echo json_encode($objArr); // Return the new updated object config
				exit(0);
			}
			else
			{
				throw new \Exception($lang['PLAN_ERROR_INVALID_ITEM'] . " ID=" . $_POST['object_id']);
			}
		}
		else
		{
			/*
			** Display html content
			*/
			if(!$isUserPerms['admin'] || ($access != 'WRITE' && $access != 'CREATOR'))
			{
				$smarty->display('no_access.html');
				exit(0);
			}

			// Object parameters
			$object = array();
			if(is_numeric($_POST['objId']))
			{
				$obj = Model_plan::instanceObjectPlans($dbconnection, $planId, array($_POST['objId']))[$_POST['objId']];
				$object = $obj->toArray($path);
			}
			elseif(isset($_POST['objParamsCommon']))
			{
				// New object not saved in DB yet
				$object = json_decode($_POST['objParamsCommon'], TRUE);
				$object['params']['getstate'] = 'yes';
				$object['link_plan_id'] = NULL;
			}

			$smarty->assign('object', $object);
			$smarty->assign('obj_getState', $object['params']['getstate']);
			$smarty->assign('onplan', $planId);
			$smarty->assign('linked', $object['link_plan_id']);

			// Get all esia nodes
			$nodes = Model_esia::getNodeList($dbconnection, $user->getId(), NULL, Model_esia::NODE_ASSOC);
			$nodesList = array();
			foreach($nodes as $node)
			{
				$nodesList[] = array('id' => $node['id'], 'name' => $node['name']);
			}
			$smarty->assign('adm_list_node', $nodesList);

			// Get all esia groups
			$groupsList = Model_esia::getNodeGroupHierarchyByUser($dbconnection, $user->getId());
			$smarty->assign('adm_list_group', $groupsList);

			// Get plans list
			$plans = Model_plan::getPlans($dbconnection, $user->getId());
			$plansList = array();
			foreach($plans as $plan)
			{
				$plansList[] = array(
					'id' => $plan['id'],
					'name' => $plan['name']
				);
			}
			$smarty->assign('plans', $plansList);

			// Get Icons menu list
			$icons = Model_plan::getIconsByGroups($dbconnection, $lang);
			$smarty->assign('icons', $icons);

			// Get configured nodes & groups
			$selectedNodes = array();
			if(!empty($object['params']['nodes']))
			{
				$selectedNodes = explode(",", $object['params']['nodes']);
			}
			$smarty->assign('selectedNodes', $selectedNodes);

			$selectedGroups = array();
			if(!empty($object['params']['groups']))
			{
				$selectedGroups = explode(",", $object['params']['groups']);
			}
			$smarty->assign('selectedGroups', $selectedGroups);

			$selectSrvNodes = array();
			$selectedServices = array();
			$servicesList = array();
			if(!empty($object['params']['services']))
			{
				$selectedServices = explode(',', $object['params']['services']);
				// Get all devices id for each service
				$services = Model_esia::getServices($dbconnection, NULL, $selectedServices);
				foreach($services as $service)
				{
					// Save device ID. Use it also as key to prevent duplication
					$selectSrvNodes[$service['device_id']] = $service['device_id'];
				}
				// Get all services data for each device
				foreach($selectSrvNodes as $nodeId)
				{
					$services = Model_esia::getServices($dbconnection, $nodeId);
					foreach($services as $service)
					{
						$common_name = Model_esia::getCommonName($lang, $service['name'], $service['check_plugin_name']);
						if(!isset($servicesList[$service['device_id']]))
						{
							// If not already set get device data for this service
							$servicesList[$service['device_id']] = array(
								'device_id' => $service['device_id'],
								'device_name' => $service['device_name'],
								'services' => array(),
							);
						}
						// Set service inside its device data array
						$servicesList[$service['device_id']]['services'][] = array(
							'id' => $service['id'],
							'name' => $common_name,
						);
					}
				}
			}
			$smarty->assign('selectSrvNodes', $selectSrvNodes);
			$smarty->assign('selectedServices', $selectedServices);
			$smarty->assign('servicesList', $servicesList);
		}
	}
	elseif($action == 'updateLink')
	{
		// Get plan user access
		$access = Model_plan::getPlanUserAccess($dbconnection, $planId, $user->getId());

		if(isset($_POST['confirmIdPlan']) && $_POST['confirmIdPlan'] == $planId)
		{
			/*
			** Validation form sended
			*/
			if(!$isUserPerms['admin'] || ($access != 'WRITE' && $access != 'CREATOR'))
			{
				throw new \Exception('Cannot update this plan object ! User privilege missing.');
			}

			if(!empty($_POST['object_id']))
			{
				$objParams = array();
				if(is_numeric($_POST['object_id']))
				{
					$_POST['object_id'] = intval($_POST['object_id']);
				}
				if(isset($_POST['obj_params_old']))
				{
					$objParams = json_decode($_POST['obj_params_old'], TRUE);
				}

				// Source & target
				if(!empty($_POST['source']))
				{
					$objParams['source'] = intval($_POST['source']);
				}
				if(!empty($_POST['target']))
				{
					$objParams['target'] = intval($_POST['target']);
				}

				// Service
				if(!empty($_POST['selectService']))
				{
					// Update service
					$objParams['service'] = $_POST['selectService'];
				}
				else
				{
					// Remove service
					$objParams['service'] = "";
				}

				// Display options
				if(!empty($_POST['isDisableArrows']))
				{
					$objParams['isDisableArrows'] = TRUE;
				}
				else
				{
					$objParams['isDisableArrows'] = FALSE;
				}
				if(!empty($_POST['isDisableLabels']))
				{
					$objParams['isDisableLabels'] = TRUE;
				}
				else
				{
					$objParams['isDisableLabels'] = FALSE;
				}

				echo json_encode($objParams); // Return the new updated object config
				exit(0);
			}
			else
			{
				throw new \Exception($lang['PLAN_ERROR_INVALID_ITEM'] . " ID=" . $_POST['object_id']);
			}
		}
		else
		{
			/*
			** Display html content
			*/
			if(!$isUserPerms['admin'] || ($access != 'WRITE' && $access != 'CREATOR'))
			{
				$smarty->display('no_access.html');
				exit(0);
			}

			if(!empty($_POST['link']))
			{
				// Object parameters
				$object = json_decode($_POST['link'], TRUE);
				$smarty->assign('object', $object);

				// Get target & source objects names
				$linkedObjects = array();
				if(!empty($object['source']) && is_numeric($object['source']) && !empty($object['target']) && is_numeric($object['target']))
				{
					$linkObj = Model_plan::getObjectsName($dbconnection, $planId, array($object['source'], $object['target']));
					$linkedObjects['source'] = array(
						'id' => $object['source'],
						'name' => $linkObj[$object['source']]
					);
					$linkedObjects['target'] = array(
						'id' => $object['target'],
						'name' => $linkObj[$object['target']]
					);
				}
				$smarty->assign('linkedObjects', $linkedObjects);

				// Services list
				$servicesList = array();
				$srvNodeId = NULL;
				if(!empty($object['service']))
				{
					// With the old plan module it was possible to set 2 services on a link. Tak only the first
					$serviceId = intval(explode(",", $object['service'])[0]);
					$srv = Model_esia::getServices($dbconnection, NULL, $serviceId)[0];
					$srvNodeId = $srv['device_id'];

					// Fetch list of all services available on this node
					if(!empty($srvNodeId ))
					{
						$servicesList = getNodeServicesList($dbconnection, $lang, $srvNodeId);
						foreach($servicesList as $key => $service)
						{
							if($service['id'] == $serviceId)
							{
								$servicesList[$key]['selected'] = TRUE;
							}
							else
							{
								$servicesList[$key]['selected'] = FALSE;
							}
						}
					}
				}
				$smarty->assign('servicesList', $servicesList);

				// Get all esia nodes
				$nodes = Model_esia::getNodeList($dbconnection, $user->getId(), NULL, Model_esia::NODE_ASSOC);
				$nodesList = array();
				$isNodeSelected = FALSE;
				foreach($nodes as $node)
				{
					$selected = FALSE;
					if($node['id'] == $srvNodeId)
					{
						$isNodeSelected = TRUE;
						$selected = TRUE;
					}
					$nodesList[] = array(
						'id' => $node['id'],
						'name' => $node['name'],
						'selected' => $selected
					);
				}
				$smarty->assign('adm_list_node', $nodesList);
				$smarty->assign('isNodeSelected', $isNodeSelected);

				// Other parameters
				$linkParams = array(
					'isDisableArrows' => FALSE,
					'isDisableLabels' => FALSE
				);
				if(!empty($object['options']['isDisableArrows']))
				{
					$linkParams['isDisableArrows'] = TRUE;
				}
				if(!empty($object['options']['isDisableLabels']))
				{
					$linkParams['isDisableLabels'] = TRUE;
				}
				$smarty->assign('linkParams', $linkParams);
			}
		}
	}
	elseif($action == 'iconAdm')
	{
		$icons = Model_plan::getIconsByGroups($dbconnection, $lang);
		$groups = Model_plan::getIconGroups($dbconnection);
		$smarty->assign('groups', $groups);
		$smarty->assign('icons', $icons);
	}
	elseif($action == 'addIconGroup')
	{
		if(isset($_POST['confirmGroupId']))
		{
			/*
			** Validation form sended
			*/
			if(!empty($_POST['name']))
			{
				if($_POST['name'] == 'ESIA')
				{
					throw new \Exception($lang['PLAN_ESIA_GRP_ICON_UNIQ']);
				}

				$groupId = Model_plan::addIconGroup($dbconnection, $_POST['name']);
				// Set vars & action to pass into updIconGroup form after adding icon completed
				$smarty->assign('group', array('id' => $groupId, 'name' => $_POST['name']));
				$smarty->assign('success', $lang['PLAN_ADD_ICON_GROUP_SUCCESS']);
				$smarty->assign('action', 'updIconGroup');
			}
			else
			{
				throw new \Exception($lang['PLAN_ERROR_ICN_GROUP_NAME']);
			}
		}
		else
		{
			/*
			** Display html content
			*/
			// Init somme var with default values
			$smarty->assign('group', array('id' => 0, 'name' => ''));
		}
	}
	elseif($action == 'updIconGroup')
	{
		if(empty($_GET['grpId']))
		{
			throw new \Exception($lang['PLAN_ERROR_ICN_GROUP_ID']);
		}
		// Check if we can update this icon group
		$group = Model_plan::getIconGroups($dbconnection, $_GET['grpId'])[0];
		if($group['name'] == 'ESIA')
		{
			throw new \Exception($lang['PLAN_ESIA_ICON_INFO']);
		}

		if(isset($_POST['confirmGroupId']) && $_POST['confirmGroupId'] == $_GET['grpId'])
		{
			/*
			** Validation form sended
			*/
			if(!empty($_POST['name']))
			{
				if($_POST['name'] == 'ESIA')
				{
					throw new \Exception($lang['PLAN_ESIA_GRP_ICON_UNIQ']);
				}

				Model_plan::updateIconGroup($dbconnection, $_GET['grpId'], $_POST['name']);

				echo json_encode(array('success' => $lang['PLAN_UPD_ICON_GROUP_SUCCESS']));
				exit(0);
			}
			else
			{
				throw new \Exception($lang['PLAN_ERROR_ICN_GROUP_NAME']);
			}
		}
		else
		{
			/*
			** Display html content
			*/
			$smarty->assign('group', $group);
		}
	}
	elseif($action == 'delIconGroup')
	{
		if(empty($_GET['grpId']))
		{
			throw new \Exception($lang['PLAN_ERROR_ICN_GROUP_ID']);
		}
		// Check if we can delete this icon group
		$group = Model_plan::getIconGroups($dbconnection, $_GET['grpId'])[0];
		if($group['name'] == 'ESIA')
		{
			throw new \Exception($lang['PLAN_ESIA_ICON_INFO']);
		}

		if(isset($_POST['confirmGroupId']) && $_POST['confirmGroupId'] == $_GET['grpId'])
		{
			/*
			** Validation form sended
			*/
			$delImgErrors = array();
			if(isset($_POST['content_action']) && $_POST['content_action'] == 'delete')
			{
				// Get all icons to remove
				$icons = Model_plan::getIconsByGroups($dbconnection, $lang, $_GET['grpId'])[$group['name']];
				// First remove all icons inside the group from DB
				Model_plan::deleteIconsByGroup($dbconnection, $_GET['grpId']);
				// Delete icons images files
				foreach($icons as $icon)
				{
					$delImgErrors = deleteFileErrorsHandler($path . $icon['path'] . $icon['name'] . "_ok." . $icon['type'], $delImgErrors);
					$delImgErrors = deleteFileErrorsHandler($path . $icon['path'] . $icon['name'] . "_warning." . $icon['type'], $delImgErrors);
					$delImgErrors = deleteFileErrorsHandler($path . $icon['path'] . $icon['name'] . "_critical." . $icon['type'], $delImgErrors);
					$delImgErrors = deleteFileErrorsHandler($path . $icon['path'] . $icon['name'] . "_unknown." . $icon['type'], $delImgErrors);
				}
			}

			// Remove the icon group & if there is still icons inside they will be placed to default group
			Model_plan::deleteIconGroup($dbconnection, $_GET['grpId']);

			if(empty($delImgErrors))
			{
				echo json_encode(array('msg' => $lang['PLAN_DEL_ICON_GROUP_SUCCESS'], 'isError' => FALSE));
			}
			else
			{
				// If there is files deletion errors send error message containing error files names to the user
				$msg = $lang['PLAN_DEL_ICON_GROUP_ERR_GROUP_FILES'];
				foreach($delImgErrors as $errFile)
				{
					$msg .= "<br>" . $errFile;
				}

				echo json_encode(array('msg' => $msg, 'isError' => TRUE));
			}

			exit(0);
		}
		else
		{
			/*
			** Display html content
			*/
			$smarty->assign('group', $group);
		}
	}
	elseif($action == 'addIconSingle')
	{
		// Add an new icon with only one image for the 4 states
		if(!empty($_FILES['logofile']) && !empty($_POST['new_name']))
		{
			// Clean file name to avoid unexpected chars like é,&,@,...
			$name = cleanUploadFileName($_POST['new_name']);
			// Check if file name already exist
			if(!empty(Model_plan::getIcons($dbconnection, NULL, $name)))
			{
				throw new \Exception($lang['PLAN_ERROR_ICN_NAME_USED']);
			}
			$group = $_POST['icon_group_select'];
			$fileExt = strtolower(pathinfo($_FILES['logofile']['name'], PATHINFO_EXTENSION));

			uploadNewIcon($path, $_FILES['logofile'], $fileExt, $name, 'ok');

			$iconId = Model_plan::addIcon($dbconnection, $name, DATA_ICONS, $fileExt, $group);

			$groupName = $lang['PLAN_ICONS_DEFAULT_GROUP'];
			if(!empty($group))
			{
				$groupName = Model_plan::getIconGroups($dbconnection, $group)[0]['name'];
			}

			$newIcon = array(
				'id' => $iconId,
				'name' => $name,
				'path' => DATA_ICONS,
				'type' => $fileExt,
				'group' => $group,
				'group_name' => $groupName
			);

			echo json_encode($newIcon);
			exit(0);
		}
		else
		{
			throw new \Exception('No file uploaded');
		}
	}
	elseif($action == 'addIconStates')
	{
		// Add an new icon with different images for the 4 states
		if(!empty($_FILES['logo_ok']) && !empty($_POST['new_name']))
		{
			// Clean file name to avoid unexpected chars like é,&,@,...
			$name = cleanUploadFileName($_POST['new_name']);
			// Check if file name already exist
			if(!empty(Model_plan::getIcons($dbconnection, NULL, $name)))
			{
				throw new \Exception($lang['PLAN_ERROR_ICN_NAME_USED']);
			}
			$group = $_POST['icon_group_select_4logos'];
			$fileExt_ok = strtolower(pathinfo($_FILES['logo_ok']['name'], PATHINFO_EXTENSION));
			$fileExt_warn = strtolower(pathinfo($_FILES['logo_warning']['name'], PATHINFO_EXTENSION));
			$fileExt_crit = strtolower(pathinfo($_FILES['logo_critical']['name'], PATHINFO_EXTENSION));
			$fileExt_unkn = strtolower(pathinfo($_FILES['logo_unknown']['name'], PATHINFO_EXTENSION));

			// All files extensions must be the same
			if($fileExt_ok == $fileExt_warn && $fileExt_ok == $fileExt_crit && $fileExt_ok == $fileExt_unkn)
			{
				uploadNewIcon($path, $_FILES['logo_ok'], $fileExt_ok, $name, 'ok');
				uploadNewIcon($path, $_FILES['logo_warning'], $fileExt_warn, $name, 'warning');
				uploadNewIcon($path, $_FILES['logo_critical'], $fileExt_crit, $name, 'critical');
				uploadNewIcon($path, $_FILES['logo_unknown'], $fileExt_unkn, $name, 'unknown');

				$iconId = Model_plan::addIcon($dbconnection, $name, DATA_ICONS, $fileExt_ok, $group);

				$groupName = $lang['PLAN_ICONS_DEFAULT_GROUP'];
				if(!empty($group))
				{
					$groupName = Model_plan::getIconGroups($dbconnection, $group)[0]['name'];
				}

				$newIcon = array(
					'id' => $iconId,
					'name' => $name,
					'path' => DATA_ICONS,
					'type' => $fileExt_ok,
					'group' => $group,
					'group_name' => $groupName
				);

				echo json_encode($newIcon);
				exit(0);
			}
			else
			{
				throw new \Exception($lang['PLAN_SAME_EXTENSION']);
			}
		}
		else
		{
			throw new \Exception('No file uploaded');
		}
	}
	elseif($action == 'updIcon')
	{
		if(empty($_GET['icnId']))
		{
			throw new \Exception($lang['PLAN_ERROR_ICN_ID']);
		}
		// Check if we can update this icon
		$icon = Model_plan::getIcons($dbconnection, $_GET['icnId'])[0];
		// Check if the icon is in a group
		if(!empty($icon['group']))
		{
			$group = Model_plan::getIconGroups($dbconnection, $icon['group'])[0];
			if($group['name'] == 'ESIA')
			{
				throw new \Exception($lang['PLAN_ESIA_ICON_INFO']);
			}
		}

		if(isset($_POST['confirmIcnId']) && $_POST['confirmIcnId'] == $_GET['icnId'])
		{
			/*
			** Validation form sended
			*/
			if(!empty($_POST['grpId']))
			{
				Model_plan::updateIconGroupId($dbconnection, $_GET['icnId'], $_POST['grpId']);

				echo json_encode(array('success' => $lang['PLAN_UPD_ICON_SUCCESS']));
				exit(0);
			}
			else
			{
				throw new \Exception($lang['PLAN_ERROR_ICN_GROUP_ID']);
			}
		}
		else
		{
			/*
			** Display html content
			*/
			$groups = Model_plan::getIconGroups($dbconnection);
			$smarty->assign('groups', $groups);
			$smarty->assign('icon', $icon);
		}
	}
	elseif($action == 'delIcon')
	{
		if(empty($_GET['icnId']))
		{
			throw new \Exception($lang['PLAN_ERROR_ICN_ID']);
		}
		// Check if we can delete this icon
		$icon = Model_plan::getIcons($dbconnection, $_GET['icnId'])[0];
		// Check if the icon is in a group
		if(!empty($icon['group']))
		{
			$group = Model_plan::getIconGroups($dbconnection, $icon['group'])[0];
			if($group['name'] == 'ESIA')
			{
				throw new \Exception($lang['PLAN_ESIA_ICON_INFO']);
			}
		}

		if(isset($_POST['confirmIcnId']) && $_POST['confirmIcnId'] == $_GET['icnId'])
		{
			/*
			** Validation form sended
			*/
			// First remove icon from DB
			Model_plan::deleteIcon($dbconnection, $_GET['icnId']);
			// Delete icons images files
			$delImgErrors = array();
			$delImgErrors = deleteFileErrorsHandler($path . $icon['path'] . $icon['name'] . "_ok." . $icon['type'], $delImgErrors);
			$delImgErrors = deleteFileErrorsHandler($path . $icon['path'] . $icon['name'] . "_warning." . $icon['type'], $delImgErrors);
			$delImgErrors = deleteFileErrorsHandler($path . $icon['path'] . $icon['name'] . "_critical." . $icon['type'], $delImgErrors);
			$delImgErrors = deleteFileErrorsHandler($path . $icon['path'] . $icon['name'] . "_unknown." . $icon['type'], $delImgErrors);

			if(empty($delImgErrors))
			{
				echo json_encode(array('msg' => $lang['PLAN_DEL_ICON_SUCCESS'], 'isError' => FALSE));
			}
			else
			{
				// If there is files deletion errors send error message containing error files names to the user
				$msg = $lang['PLAN_DEL_ICON_ERR_FILES'];
				foreach($delImgErrors as $errFile)
				{
					$msg .= "<br>" . $errFile;
				}

				echo json_encode(array('msg' => $msg, 'isError' => TRUE));
			}

			exit(0);
		}
		else
		{
			/*
			** Display html content
			*/
			$smarty->assign('icon', $icon);
		}
	}
}
catch(\EsiaDbException | \Plan\PlanException | \Exception $e)
{
	$errors[] = $e->getMessage();
}

if($isJSONResp == TRUE)
{
	echo json_encode(array('error' => $errors));
	exit(0);
}
else
{
	$smarty->assign('errors', $errors);
}

$smarty->display($templatePath . 'dialog_img.html');

?>
