// Init plan container object configuration
function initContainerObjConf(obj, planId, admLists) {
	$("#selectNodes").chosen({no_results_text: glob_lang.SEARCH_NONE, search_contains:true});
	$("#selectGroups").chosen({no_results_text: glob_lang.SEARCH_NONE, search_contains:true});
	$("#selectSrvNode").chosen({no_results_text: glob_lang.SEARCH_NONE, search_contains:true});
	$("#selectServices").chosen({no_results_text: glob_lang.SEARCH_NONE, search_contains:true});
	$("#selectPlan").chosen({no_results_text: glob_lang.SEARCH_NONE, search_contains:true});

	setOptsServiceByDeviceChange();
	updObjContainerEvent(obj);
}

// Set new service options in select element when a new device is selected in obj conf services
function setOptsServiceByDeviceChange() {
	$('#selectSrvNode').on('change', function() {
		// Current node ids selected
		let newNodeIds = $(this).val() || [];

		// Enable/disable select service if nodes are selected or not
		const isDisabled = newNodeIds.length > 0 ? false : true;
		$('#selectServices').prop('disabled', isDisabled);

		// Get the previous selected node ids to add/remove services from it in the list
		let oldNodeIds = [];
		$('#selectServices optgroup').each(function() {
			// Get previously adde node ids form the select optgroups
			oldNodeIds.push($(this).attr('data-id'));
		});

		// Get nodes ids to add or remove
		let addNodeIds = Utils.array_diff(newNodeIds, oldNodeIds);
		let removeNodeIds = Utils.array_diff(oldNodeIds, newNodeIds);

		// Delete services from devices removed
		removeNodeIds.forEach(nodeId => {
			$('#selectServices optgroup[data-id="' + nodeId + '"]').remove();
		});

		// Add services from added devices
		addNodeIds.forEach(nodeId => {
			// Get node name from node select options
			const nodeName = $('#selectSrvNode option[value="' + nodeId + '"]').text();
			// Create new optgroup
			const optgroup = $('<optgroup>', { label: nodeName, 'data-id': nodeId });
			$('#selectServices').append(optgroup);
			// Create services options
			updSelectService(nodeId, $('#selectServices'), true, optgroup);
		});

		$("#selectServices").trigger("chosen:updated");
	});
}

// Handle saving new object configuration parameters
function updObjContainerEvent(obj) {
	$("#formUpdObjContainer").on('submit', function(e) {
		e.preventDefault();

		var formData = getFormValues('formUpdObjContainer'),
			objParams = {};

		if(!$.isNumeric(obj.id)) {
			objParams = JSON.stringify(obj.params);
		}

		$.ajax({
			type: "POST",
			url: $(this).attr("action"),
			data: { isJSONResp: true, ...formData, obj_params_old: objParams },
			dataType: "json"
		})
		.done(function(data) {
			if (data.error) {
				// Error Message
				displayUserMessage(data.error, true, 'dialog-messages');
			} else {
				const objParams = {
					id: data.old_id,
					options: {
						id: data.id,
						name: data.name,
						icon: {
							id: data.icon_id,
							path: data.icon_file.path
						}
					}
				};

				window.planImgApp.updateContainerNodes([ objParams ]);
				window.planImgApp.repaint();

				// Close dialog window
				$("#dialog-info").dialog("close");
			}
		});
	});
}

// Init plan object link configuration
function initLinkConf(obj, planId, nodesList) {
	$("#formUpdLink .selectNode").chosen({no_results_text: glob_lang.SEARCH_NONE, search_contains: true, allow_single_deselect: true});
	$("#formUpdLink .selectService").chosen({no_results_text: glob_lang.SEARCH_NONE, search_contains: true, allow_single_deselect: true});

	selectServicesEvents();
	reverseLinkEvents();
	updObjLinkEvent(obj, planId);
}

// Handle node & service selection change
function selectServicesEvents()
{
	$("#formUpdLink .selectNode").on('change', function() {
		var nodeId = $(this).val();

		if(nodeId != "") {
			$("#formUpdLink .selectService").empty().prop('disabled', false);
			updSelectService(nodeId, $("#formUpdLink .selectService"));
		} else {
			$("#formUpdLink .selectService").empty().prop('disabled', true);
		}
		$("#formUpdLink .selectService").trigger("chosen:updated");
	});
}

// Handle link reverse action
function reverseLinkEvents()
{
	$("#formUpdLink .link-reverse").on("click", function() {
		var src = {
				id: $('#source').val(),
				name: $('.link-src').text()
			},
			tar = {
				id: $('#target').val(),
				name: $('.link-tar').text()
			};

		$('#source').val(tar.id);
		$('#target').val(src.id);
		$('.link-src').text(tar.name);
		$('.link-tar').text(src.name);
	});
}

// Handle saving new object configuration parameters
function updObjLinkEvent(obj, planId) {
	$("#formUpdLink").on('submit', function(e) {
		e.preventDefault();

		var formData = getFormValues('formUpdLink'),
			objParams = JSON.stringify(obj);

		$.ajax({
			type: "POST",
			url: $(this).attr("action"),
			data: { isJSONResp: true, ...formData, obj_params_old: objParams },
			dataType: "json"
		})
		.done(function(data) {
			if (data.error) {
				// Error Message
				displayUserMessage(data.error, true, 'dialog-messages');
			} else {
				const objParams = {
					id: data.id,
					options: {
						service: data?.service || '',
						source: data.source,
						target: data.target,
						points: data?.points || [],
						isDisableArrows: data.isDisableArrows || false,
						isDisableLabels: data.isDisableLabels || false
					}
				};

				window.planImgApp.updateServiceLinks([ objParams ]);
				window.planImgApp.repaint();

				// Close dialog window
				$("#dialog-info").dialog("close");
			}
		});
	});
}

// Before sending new logo check if all required fields are filled & send form as AJAX request
function addAdmIcon(formHtmlId) {
	// Set green border on input files when an image is selected
	$('input[type="file"]', '#' + formHtmlId).on('change', function() {
		$(this).parent().find('label').css("border-color", "#83BC00");
	});

	$('#' + formHtmlId).on('submit', function(e) {
		let isError = false;

		// Prevent form submit to check inputs first
		e.preventDefault();

		// Check all file inputs and prevent submit form if some are missing
		$('input[type="file"]', '#' + formHtmlId).each(function() {
			if($(this).get(0).files.length === 0) {
				$(this).parent().find('label').css("border-color", "#DA002E");
				isError = true;
			} else {
				$(this).parent().find('label').css("border-color", "#83BC00");
			}
		});

		// If no errors on inputs send the form as AJAX request
		if(!isError) {
			$.ajax({
				type: "POST",
				url: $(this).attr("action") + '&isJSONResp=true',
				data: new FormData(this),
				processData: false,
				contentType: false,
				dataType: "json"
			})
			.done(function(data) {
				if(data.id) {
					const iconsGroupList = $('.iconMenuList > ul');
					const groupContainerSelector = 'li[data-group-id="' + data.group + '"]';
					let groupContainer = $(groupContainerSelector, iconsGroupList);
					const iconItem = $("<li>", { class: 'imgMove', title: data.name, 'data-icon-id': data.id, html:
						'<img src="' + data.path + data.name + '_ok.' + data.type + '">'
					});

					if(groupContainer.length == 0) {
						// Icon group not listed yet
						groupContainer = $("<li>", { class: 'toggleSubMenu', 'data-group-id': data.group, 'data-group-name': data.group_name, html:
							'<span class="subMenuTitle">' + data.group_name + '</span>' +
							'<ul class="subMenu">' +
							'</ul>'
						});

						iconsGroupList.append(groupContainer);
					}

					// Selector must be rewrite from iconsGroupList to reactualize children
					$(groupContainerSelector + ' .subMenu', iconsGroupList).append(iconItem);

					// Clean form
					$('#' + formHtmlId)[0].reset();
					$('#' + formHtmlId + ' .chooseIcons label').css("border-color", "");

					// Re init click menu icon events
					toggleIconsMenu('.iconMenuList', groupContainerSelector);
					handleIconsSelectActions();

					// Success message
					displayUserMessage(glob_lang.PLAN_UPL_ICON_SUCCESS, false, 'dialog-messages');
				}
				else if (data.error) {
					// Error Message
					displayUserMessage(data.error, true, 'dialog-messages');
				}
			})
			.fail(function(jqXHR, errMsg) {
				displayUserMessage("AJAX Request failed: " + errMsg, true, 'dialog-messages');
			});
		}
	});
}

// Open admIcon dialog on add group page
function openAdmIconAddGroup() {
	$('.addIconGroup').on("click", function() {
		$.ajax({
			type: "GET",
			url: glob_apache_path + "dialog_img.php?action=addIconGroup&id=" + glob_plan.id,
			data: {},
			dataType: "html"
		})
		.done(function(data) {
			if(data) {
				$('#dialog-info').empty();
				$('#dialog-info').append(data);
			}
		});
	});
}

// Open admIcon dialog on update group page
function openAdmIconUpdGroup() {
	$('.updIconGroup').on("click", function() {
		$.ajax({
			type: "GET",
			url: glob_apache_path + "dialog_img.php?action=updIconGroup&id=" + glob_plan.id + "&grpId=" + $(this).attr('data-group-id'),
			data: {},
			dataType: "html"
		})
		.done(function(data) {
			if(data) {
				$('#dialog-info').empty();
				$('#dialog-info').append(data);
			}
		});
	});
}

// Add a new icon group
function addIconGroup() {
	$("#formIconGroup").on('submit', function(e) {
		e.preventDefault();

		var formData = getFormValues('formIconGroup');

		$.ajax({
			type: "POST",
			url: $(this).attr("action"),
			data: { ...formData },
			dataType: "html"
		})
		.done(function(data) {
			if(data) {
				$('#dialog-info').empty();
				$('#dialog-info').append(data);
			}
		});
	});
}

// Update an icon group
function updIconGroup() {
	$("#formIconGroup").on('submit', function(e) {
		e.preventDefault();

		var formData = getFormValues('formIconGroup');

		$.ajax({
			type: "POST",
			url: $(this).attr("action"),
			data: { isJSONResp: true, ...formData },
			dataType: "json"
		})
		.done(function(data) {
			if (data.error) {
				// Error Message
				displayUserMessage(data.error, true, 'dialog-messages');
			} else if (data.success) {
				displayUserMessage(data.success, false, 'dialog-messages');
			}
		});
	});
}

// On admIcon dialog go back to main window
function goBackToAdmIcon(savedMessage={ msg: '', isError: true }) {
	$.ajax({
		type: "GET",
		url: glob_apache_path + "dialog_img.php?action=iconAdm&id=" + glob_plan.id,
		data: {},
		dataType: "html"
	})
	.done(function(data) {
		if(data) {
			$('#dialog-info').empty();
			$('#dialog-info').append(data);
			// Display message after page refresh
			if(savedMessage.msg != '') {
				displayUserMessage(savedMessage.msg, savedMessage.isError, 'dialog-messages');
			}
		}
	});
}

// On admIcon dialog go back to main window on cancel btn click
function cancelGroupAdm(savedMessage={}) {
	$('.btnBack').on("click", function() {
		goBackToAdmIcon();
	});
}

// Open admIcon dialog on delete group confirmation page
function openAdmIconDelGroup() {
	$('.delIconGroup').on("click", function() {
		$.ajax({
			type: "GET",
			url: glob_apache_path + "dialog_img.php?action=delIconGroup&id=" + glob_plan.id + "&grpId=" + $(this).attr('data-group-id'),
			data: {},
			dataType: "html"
		})
		.done(function(data) {
			if(data) {
				$('#dialog-info').empty();
				$('#dialog-info').append(data);
			}
		});
	});
}

// Delete an icon group
function delIconGroup() {
	$("#formDelIconGroup").on('submit', function(e) {
		e.preventDefault();

		var formData = getFormValues('formDelIconGroup');

		$.ajax({
			type: "POST",
			url: $(this).attr("action"),
			data: { isJSONResp: true, ...formData },
			dataType: "json"
		})
		.done(function(data) {
			if (data.error) {
				// Error Message
				displayUserMessage(data.error, true, 'dialog-messages');
			} else if (data.msg) {
				goBackToAdmIcon({ msg: data.msg, isError: data.isError });
			}
		});
	});
}

// Open admIcon dialog on update icon page
function openAdmIconUpdIcon(iconId) {
	if(iconId != '') {
		$.ajax({
			type: "GET",
			url: glob_apache_path + "dialog_img.php?action=updIcon&id=" + glob_plan.id + "&icnId=" + iconId,
			data: {},
			dataType: "html"
		})
		.done(function(data) {
			if(data) {
				$('#dialog-info').empty();
				$('#dialog-info').append(data);
			}
		});
	}
}

// Open admIcon dialog on delete icon confirm page
function openAdmIconDelIcon(iconId) {
	if(iconId != '') {
		$.ajax({
			type: "GET",
			url: glob_apache_path + "dialog_img.php?action=delIcon&id=" + glob_plan.id + "&icnId=" + iconId,
			data: {},
			dataType: "html"
		})
		.done(function(data) {
			if(data) {
				$('#dialog-info').empty();
				$('#dialog-info').append(data);
			}
		});
	}
}

// Set styles for selected icon and activate modify & delete buttons
function handleIconsSelectActions() {
	const iconAdmList = $('.iconAdm .menuIcons');
	const menuIconsActions = $('.menuIconsActions', iconAdmList);

	// Reset for reapplying events
	$('.imgMove.active', iconAdmList).removeClass('active');

	$('.imgMove', iconAdmList)
	.off('.admIconSelect') // Reset event in case it was already set on somme elements and need to be reaply on all of them
	.on('click.admIconSelect', function() {
		// Handle active class for styles
		$('.imgMove.active', iconAdmList).not(this).removeClass('active');
		$(this).toggleClass('active');
		// Display the modify & delete buttons if something is selected
		if($(this).hasClass('active')) {
			menuIconsActions.show();
		} else {
			menuIconsActions.hide();
		}
		// Disable the modify & delete buttons for the ESIA group which contain default icons and cannot be modify or delete
		if($(this).closest('.toggleSubMenu').attr('data-group-name') == 'ESIA') {
			$('button', menuIconsActions).prop('disabled', true).attr('title', glob_lang.PLAN_ESIA_ICON_INFO);
		} else if($('button', menuIconsActions).prop('disabled') == true) {
			$('button', menuIconsActions).prop('disabled', false);
			$('.btnIconActionUpd', menuIconsActions).attr('title', glob_lang.MODIF);
			$('.btnIconActionDel', menuIconsActions).attr('title', glob_lang.DELETE);
		}
	});

	// Reset icon selection on menu group open close action
	$('.toggleSubMenu .subMenuTitle', iconAdmList)
	.off('.admIconSelect')
	.on('click.admIconSelect', function() {
		$('.imgMove.active', iconAdmList).removeClass('active');
		menuIconsActions.hide();
	});

	// Actions on modify btn click
	$('.btnIconActionUpd', menuIconsActions)
	.off('.admIconSelect')
	.on('click.admIconSelect', function() {
		const iconId = $('.imgMove.active', iconAdmList).attr('data-icon-id') || '';
		openAdmIconUpdIcon(iconId);
	});

	// Actions on delete btn click
	$('.btnIconActionDel', menuIconsActions)
	.off('.admIconSelect')
	.on('click.admIconSelect', function() {
		const iconId = $('.imgMove.active', iconAdmList).attr('data-icon-id') || '';
		openAdmIconDelIcon(iconId);
	});
}

// Update an icon
function updIcon() {
	$("#formIconUpd").on('submit', function(e) {
		e.preventDefault();

		var formData = getFormValues('formIconUpd');

		$.ajax({
			type: "POST",
			url: $(this).attr("action"),
			data: { isJSONResp: true, ...formData },
			dataType: "json"
		})
		.done(function(data) {
			if (data.error) {
				// Error Message
				displayUserMessage(data.error, true, 'dialog-messages');
			} else if (data.success) {
				displayUserMessage(data.success, false, 'dialog-messages');
			}
		});
	});
}

// Delete an icon group
function delIcon() {
	$("#formDelIcon").on('submit', function(e) {
		e.preventDefault();

		var formData = getFormValues('formDelIcon');

		$.ajax({
			type: "POST",
			url: $(this).attr("action"),
			data: { isJSONResp: true, ...formData },
			dataType: "json"
		})
		.done(function(data) {
			if (data.error) {
				// Error Message
				displayUserMessage(data.error, true, 'dialog-messages');
			} else if (data.msg) {
				goBackToAdmIcon({ msg: data.msg, isError: data.isError });
			}
		});
	});
}
